@@ -34,7 +34,7 @@ has 'stream_type' => (
 		my $self = shift;
 		return 'url' if $self->stream =~ m{^http}xms;
 		return 'string' if $self->stream =~ m{\<\?xml}xms;
-		return 'file' if $self->stream =~ m{(\.xml|\.html|\.txt|\.json)}xms; 
+		return 'file' if $self->stream =~ m{(\.xml|\.html|\.txt|\.json|\.csv)}xms; 
 	}
 );
 
